.. _spider_oe1.orf.at:

oe1.orf.at
----------
Newest episodes of radio shows from `ORF Ö1 <https://oe1.orf.at>`_.

Configuration
~~~~~~~~~~~~~
Add ``oe1.orf.at`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     oe1.orf.at

